module.exports = {
    /**
     * 设置Cookie
     * @param {string} key Cookie名
     * @param {string} val Cookie值
     * @param {number} expires 隐含参数，表示过期时间，单位为秒
     * @param {string} domain  隐含参数，域
     */
    setItem: function (key, val/*,expires,domain*/) {
        var expires = arguments[2],
            domain = arguments[3],
            date = new Date();

        if(!expires) { date.setTime(date.getTime() + 1000 * 60 * 60); }//默认1小时过期
        else { date.setTime(date.getTime() + expires * 1000 ); }  

        if(null == domain) domain = document.domain;
        document.cookie = key + "=" + encodeURIComponent(val) + "; expires=" + date.toGMTString() + "; path=/; domain=" + domain;
    },
    /**
     * 取得Cookie名对应的Cookie值
     * @param {string} key Cookie名
     * @return {string}
     */
    getItem: function (key) {
        var cookies = document.cookie.split("; ");//一个分号加一个空格
        if (!cookies.length) {return "";}

        for (var i = 0, c; i < cookies.length; i++) {
            c = cookies[i].split("=");//以赋值号分隔,第一位是Cookie名,第二位是Cookie值
            if (c[0] == key) {
                return decodeURIComponent(c[1]);
            }
        }

        return "";
    },
    /**
     * 取得所有的Cookie
     * @return {string}
     */
    getAll: function () {
        return document.cookie || "";
    },
    /**
     * 移除Cookie名对应的Cookie
     * @param {string} key Cookie名
     * @param {string} domain  隐含参数，域
     */
    removeItem: function (key/*, domain*/) {
        var expires = new Date();
        expires.setTime(expires.getTime() - 1);//将expires设为一个过去的日期，浏览器会自动删除它
        this.setItem(key, "", expires, arguments[1]);
    },
    /**
     * 移除所有的Cookie
     */
    clear: function (/*domain*/) {
        var expires = new Date();
        expires.setTime(expires.getTime() - 1);//过去的日期
        var cookies = document.cookie.split("; ");//一个分号加一个空格

        if (!cookies.length) return;

        for (var i = 0,c; i < cookies.length; i++) {
            c = cookies[i].split("=");
            this.setItem(c[0], "", expires, arguments[0]);
        }    
    }
};

